@@ -71,15 +71,14 @@ BayonneBinder("ivrscript1")
 			(Check)&Checks::chkJoin},
 		{"recall", false, (Method)&Methods::scrRecall,
 			(Check)&Checks::chkRecall},
+		{"feature", false, (Method)&Methods::scrFeature,
+			(Check)&Checks::chkFeature},
 		{"release", true, (Method)&Methods::scrRelease,
 			(Check)&Checks::chkRecall},
 		{"reconnect", false, (Method)&Methods::scrReconnect,
 			(Check)&Checks::chkReconnect},
                 {NULL, false, NULL, NULL}}; 
 
-	char buf[256];
-	const char *cp;
-
 	bind(interp);
 	slog.info("binding ivrscript...");
 	PersistProperty::load();
@@ -95,15 +94,8 @@ BayonneBinder("ivrscript1")
 	Bayonne::use_macros = true;
 	Bayonne::use_merge = true;
 
-	cp = server->getLast("serverconfig");
-	if(cp)
-	{
-		snprintf(buf, sizeof(buf), "%s/%s/connect.conf",
-			CONFIG_FILES, cp);
-		server->setValue("connect.conf", buf);
-	}
-	else
-		server->setValue("connect.conf", CONFIG_FILES "/connect.conf");
+	server->setValue("connect.conf", CONFIG_FILES "/connect.conf");
+	server->setValue("feature.conf", CONFIG_FILES "/feature.conf");
 };
 
 bool Binder::select(ScriptInterp *interp)
