@@ -199,9 +199,6 @@ const char *Checks::chkRegister(Line *line, ScriptImage *img)
 	if(scr->access != ScriptInterp::scrPUBLIC)
 		return "cannot register non-public script";
 
-	if(cp)
-		++cp;
-
 	if(ext && !stricmp(ext, ".conf"))
 	{
 		if(cp)
@@ -270,9 +267,6 @@ const char *Checks::chkAssign(Line *line, ScriptImage *img)
 	if(!strnicmp(line->cmd, "incoming.", 9))
 		return "invalid member for incoming"; 
 
-	if(cp && *cp == '.')
-		++cp;
-
 	if(cp)
 	{
 		if(!stricmp(cp, "timeslot"))
@@ -427,9 +421,6 @@ drivermode:
 trunking:
 	img->setPointer(sbuf, scr);
 
-	if(cp && *cp == '.')
-		++cp;
-
 	if(cp)
 	{
 		if(!stricmp(cp, "timeslot"))
