@@ -2790,6 +2790,13 @@ protected:
         void addKey(const char *key, const char *value, const char *field = NULL);
 
 public:
+	struct {
+		unsigned replycode;		// 200 = ok...
+		const char *replytext;
+		const char *authorization;	// user:secret
+		bool authorized;	// authorized by web server...
+	}	http;
+
         struct {
                 const char *method;
                 const char *tranid;
