@@ -38,8 +38,9 @@ const char *BayonneBinder::submit(const char **args)
 	return NULL;
 }
 
-void BayonneBinder::billing(BayonneSession *p, BayonneSession *c, time_t start)
+void BayonneBinder::report(Call *call)
 {
+	delete call;
 }
 
 ScriptCompiler *BayonneBinder::compiler(void)
@@ -70,8 +71,8 @@ const char *BayonneBinder::submitRequest(const char **args)
 {
 	return binder->submit(args);
 }
-	
-void BayonneBinder::reportBilling(BayonneSession *p, BayonneSession *c, time_t start)
+
+void BayonneBinder::reportCall(Call *call)
 {
-	return binder->billing(p,c,start);
-}
+	return binder->report(call);
+}	
