@@ -39,6 +39,54 @@ void BayonneService::stopService(void)
 	terminate();
 }
 
+void BayonneService::detachCall(BayonneSession *s)
+{
+}
+
+void BayonneService::activeCall(BayonneSession *s)
+{
+}
+
+void BayonneService::notifyCall(BayonneSession *s)
+{
+}
+
+void BayonneService::notify(BayonneSession *s)
+{
+        BayonneService *svc = first;
+
+        while(svc && svc != last)
+        {
+                last = svc;
+                svc->notifyCall(s);
+                svc = svc->next;
+        }
+}
+
+void BayonneService::detach(BayonneSession *s)
+{
+        BayonneService *svc = first;
+
+        while(svc && svc != last)
+        {
+                last = svc;
+                svc->detachCall(s);
+                svc = svc->next;
+        }
+}
+
+void BayonneService::active(BayonneSession *s)
+{
+        BayonneService *svc = first;
+
+        while(svc && svc != last)
+        {
+                last = svc;
+                svc->activeCall(s);
+                svc = svc->next;
+        }
+}
+
 void BayonneService::start(void)
 {
 	BayonneService *svc = first;
