@@ -2128,7 +2128,7 @@ bool BayonneSession::stateSeize(Event *event)
 		}
 		if(event->tone.exit)
 		{
-			slog.debug("%s: %s; exiting", logname, event->tone.name);
+			slog.notice("%s: %s; exiting", logname, event->tone.name);
 			setState(STATE_HANGUP);
 		}
 		return true;
@@ -2215,7 +2215,7 @@ failure:
 			setRunning();
 			return true;
 		}
-		slog.debug("%s: no dialtone; exiting", logname);
+		slog.notice("%s: no dialtone; exiting", logname);
 		setSymbol("script.error", "session-failed");
 		setState(STATE_HANGUP);
 		return true;
@@ -2319,7 +2319,7 @@ bool BayonneSession::stateThreading(Event *event)
 		startTimer(thread->getTimeout());
 		return true;
 	case TIMER_EXPIRED:	// use common handler...
-		slog.debug("%s: thread expired", logname);
+		slog.warn("%s: thread expired", logname);
 	default:
 	        return enterCommon(event);
 	}
