@@ -106,9 +106,6 @@ void Driver::startDriver(void)
 	if(cp)
 		max_count = atoi(cp);
 
-	peer_encoding = Audio::pcm16Mono;
-	peer_framing = 20;
-
         if (!endpoint.Initialise())
         {
 		slog.error() << "h323: the endpoint failed to initialise" << endl;
