@@ -80,28 +80,8 @@ BayonneDriver(driver, "/bayonne/driver/sangoma", "sangoma", false)
 	else if(cp && !stricmp(cp, "mulaw"))
 		info.encoding = Audio::mulawAudio;
 */
-	switch(peer_encoding)
-	{
-	case Audio::unknownEncoding:
-                peer_encoding = info.encoding;
-		break;
-	case Audio::pcm16Mono:
-		info.encoding = Audio::pcm16Mono;
-		break;
-/*	case Audio::mulawAudio:
-		info.encoding = Audio::mulawAudio;
-		break;
-	case Audio::alawAudio:
-		info.encoding = Audio::alawAudio;
-		break;
-*/
-	}
-
 	info.set();
 
-        if(peer_framing == 0)
-                peer_framing = Audio::getFraming(peer_encoding, 20);
-
 	server->setValue("timeslot.conf", CONFIG_FILES "/timeslot.conf");
         server->setValue("caller.conf", CONFIG_FILES "/caller.conf");
         server->setValue("dialed.conf", CONFIG_FILES "/dialed.conf");
