@@ -37,6 +37,9 @@ BayonneService(0, 0), Keydata("/bayonne/module/tcpmon")
 	        load("~bayonne/tcpmon");
 
 	load(defkeys);
+#ifdef	WIN32
+	loadFile("C:\\Program Files\\GNU Telephony\\Bayonne Config\\module.ini", "tcpmon");
+#endif
 
 }
 
