@@ -14,10 +14,17 @@
 // along with this program; if not, write to the Free Software 
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
+#include <private.h>
 #include <bayonne.h>
 #include <cc++/slog.h>
 #include <cc++/socket.h>
 
+#ifdef  WIN32
+#define WEBSERVER_FILES "C:\\Program Files\\GNU Telephony\\Bayonne Webserver"
+#else
+#define WEBSERVER_FILES SHARED_FILES "/webserver"
+#endif
+
 namespace moduleWebservice {
 using namespace ost;
 using namespace std;
@@ -38,7 +45,7 @@ public:
 	Service();
 };
 
-class Session : public Socket, public Thread, public Bayonne
+class Session : public BayonneRPC, public Socket, public Thread
 {
 protected:
 	char buffer[1024];
@@ -56,9 +63,11 @@ protected:
 	void sendAuth(const char *text, const char *ctype = NULL);
 	void sendError(const char *text, const char *ctype = NULL);
 	void sendHeader(const char *ctype = "text/html", unsigned long clen = 0);
-	void xmlrpcFault(int code, const char *text);
-	void xmlrpcReply(const char *string = NULL);	
+	void rpcFault(int code, const char *text);
+	void rpcReply(const char *string = NULL);	
 
+	unsigned long htmlAccess(const char *fname);
+	void htmlInsert(const char *section, const char *title);
 	void htmlHeader(const char *title, bool refresh);
 	void htmlFooter(void);
 	void htmlStatus(void);
