@@ -237,6 +237,56 @@ void Session::xmlStart(void)
 	xmlFooter();
 }
 
+void Session::xmlRefer(void)
+{
+	char *tok;
+	const char *sid = NULL;
+	BayonneSession *s;
+	char *target = NULL;
+	Event event;
+
+	if(req_query)
+		req_query = strtok_r(req_query, "&\r\n", &tok);
+
+	while(req_query)
+	{
+		if(!strnicmp(req_query, "target=", 7))
+		 	target = urlDecode(req_query + 7);
+		else if(!strnicmp(req_query, "session=", 8))
+			sid = urlDecode(req_query + 8);
+		req_query = strtok_r(NULL, "&\r\n", &tok);
+	}
+	if(!target || !sid)
+		xmlFault(XML_ARGUMENT_MISSING, "refer");
+	
+	s = getSid(sid);
+	if(!s)
+		xmlFault(XML_SESSION_INVALID, "refer");
+
+	s->enterMutex();
+	if(!s->isJoined())
+	{
+		s->leaveMutex();
+		xmlFault(XML_COMMAND_FAILED, "refer");
+	}
+	if(!s->isHolding())
+	{
+		s->leaveMutex();
+		xmlFault(XML_COMMAND_FAILED, "refer");
+	}
+	memset(&event, 0, sizeof(event));
+	event.id = START_REFER;
+	event.dialing = target;
+	if(!s->postEvent(&event))
+	{
+		s->leaveMutex();
+		xmlFault(XML_COMMAND_FAILED, "refer");
+	}
+	s->leaveMutex();
+	xmlHeader("refer");
+	xmlSuccess();
+	xmlFooter();
+}
 	
 void Session::xmlRegistrations(void)
 {
@@ -380,6 +430,7 @@ void Session::xmlStatus(void)
 	BayonneSession *s = NULL;
 	char *sid = NULL;
 	char *tok;
+	const char *stat;
 
 	if(req_query)
 		req_query = strtok_r(req_query, "&\r\n", &tok);
@@ -396,7 +447,15 @@ void Session::xmlStatus(void)
 		if(s)
 		{
 			xmlHeader("status");
-			xmlSuccess();
+			if(s->isRefer())
+				stat = "refer";
+			else if(s->isHolding())
+				stat = "holding";
+			else
+				stat = "success";
+			snprintf(buffer, sizeof(buffer),
+				"  <result id=\"command\" value=\"%s\"/>\r\n", stat);	
+			sendText(buffer);		
 			xmlFooter();
 		}
 		else
