@@ -23,7 +23,7 @@ namespace moduleWebservice {
 using namespace ost;
 using namespace std;
 
-void Session::xmlrpcFault(int code, const char *string)
+void Session::rpcFault(int code, const char *string)
 {
 	char buf[28];
 	snprintf(buf, sizeof(buf), "<int>%d</int>", code);
@@ -45,7 +45,7 @@ void Session::xmlrpcFault(int code, const char *string)
 	syncExit();
 }
 
-void Session::xmlrpcReply(const char *string)
+void Session::rpcReply(const char *string)
 {
 	strcpy(buffer, "<?xml version=\"1.0\"?>\r\n");
 	strcat(buffer, "<methodResponse>\r\n");
