@@ -258,7 +258,7 @@ const char *Checks::chkLibexec(Line *line, ScriptImage *img)
 	const char *cp = getMember(line);
 	unsigned idx = 0;
 
-	if(cp && atoi(++cp) < 1)
+	if(cp && atoi(cp) < 1)
 		return "libexec timeout member must be at least one second";
 
 	if(!strnicmp(line->cmd, "exec", 4))
@@ -493,7 +493,7 @@ const char *Checks::chkRecord(Line *line, ScriptImage *img)
 	const char *cp;
 
 	cp = getMember(line);
-	if(cp && stricmp(cp, ".vox"))
+	if(cp && stricmp(cp, "vox"))
 		return "use no member or .vox only";
 
 	if(!useKeywords(line, "=extension=encoding=prefix=framing=silence=intersilence=note=position=exit=timeout=menu"))
@@ -533,7 +533,7 @@ const char *Checks::chkAppend(Line *line, ScriptImage *img)
 	const char *cp;
 
 	cp = getMember(line);
-	if(cp && stricmp(cp, ".vox"))
+	if(cp && stricmp(cp, "vox"))
 		return "use no member or .vox only";
 
 	if(!useKeywords(line, "=extension=encoding=prefix=framing=silence=intersilence=exit=timeout"))
